# NHANES pyTOOL API

The NHANES pyTOOL 'API' is a Python library designed to simplify the process of accessing and analyzing data from the National Health and Nutrition Examination Survey (NHANES). NHANES is a program of studies conducted by the National Center for Health Statistics (NCHS), part of the Centers for Disease Control and Prevention (CDC), to assess the health and nutritional status of adults and children in the United States.

This tool provides an easy-to-use interface for retrieving NHANES datasets, allowing researchers, data science professionals, health professionals, developers and other stakeholders to explore NHANES data efficiently, enabling a wide range of health-related analyses and applications.


**Attention:** Please take a look at the [Disclaimer](https://kkrusere.github.io/NHANES-pyTOOL-API/#disclaimer) before using the tool

## Features

- **List Data Categories:** Retrieve a list of available NHANES data categories.
- **List Cycle Years:** Get a list of available NHANES cycle years.
- **Retrieve Variable Tables:** Fetch variable tables for specific data categories.
- **Get Data File Descriptions:** Obtain unique data file descriptions for a given data category and cycle years.
- **Retrieve Data:** Fetch data for specific data categories, cycle years, and data file descriptions.
- **Join Data Files:** Join data files based on common variables.
- **Find Common and Uncommon Variables:** Identify common and uncommon variables across multiple cycle years.


## Installation

To install the NHANES pyTOOL API, use `pip`:

```bash
pip install nhanes_pytool_api
```



# Important Note

**Attention:** In the current version of the NHANES pyTOOL API (version 0.1.1), we do not provide a command-line interface (CLI) for direct use from the terminal. This means that you cannot run the API from the command line to access NHANES data. Instead, the API is designed for use as a library in Python scripts or applications.
###### Future Updates - We are continuously improving the NHANES Data API, and in future versions, we may consider adding a command-line interface for easier interaction with the API from the terminal. Until then, please use the API in your Python scripts or applications.


## Documentation

For detailed information on how to use the NHANES pyTOOL API, check out the [documentation](https://kkrusere.github.io/NHANES-pyTOOL-API/).

## Contributing

Contributions are welcome! For major changes, please open an issue first to discuss what you would like to change.


## GitHub Issue

If you encounter any issues, bugs, or have suggestions for improvements, please use our [GitHub Issue](https://github.com/kkrusere/NHANES-pyTOOL-API/issues). Our development team actively monitors this repository, and this is the recommended way to report problems or suggest enhancements. To help us address your issue effectively, please follow these guidelines:

1. **Search Existing Issues:** Before creating a new issue, please search the existing issues to check if someone has already reported a similar problem or request. If you find a related issue, you can contribute to the existing discussion.

2. **Provide Details:** When reporting a bug, provide as much detail as possible about the problem you encountered. Include information about your environment, code, and any error messages you received. For feature requests, explain your use case and how the proposed feature would benefit the project.

3. **Be Respectful:** Remember to be respectful and constructive in your interactions with other contributors. A positive and collaborative environment helps improve the project for everyone.

4. **Use Labels:** Our issue tracker uses labels to categorize and prioritize issues. These labels help us identify the nature of each issue. You can use labels such as "bug," "enhancement," or "question" to classify your issue.

Our team will review and respond to issues as soon as possible. Thank you for your contributions and feedback!

[**GitHub Issue**](https://github.com/kkrusere/NHANES-pyTOOL-API/issues)



## License

This project is licensed under the MIT License - see the [LICENSE](https://github.com/kkrusere/NHANES-pyTOOL-API/blob/main/LICENSE.txt) file for details.
